.. airtest documentation master file, created by
   sphinx-quickstart on Mon Mar  7 13:34:33 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to airtest's documentation!
===================================

Documentation
-------------

.. toctree::
    :titleonly:

.. automodule:: airtest
    :undoc-members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

